User prompt
tabloyu biraz yukarı taşı
User prompt
tabloyu biraz yukarı taşı
User prompt
tabloyu biraz yukarı taşı
User prompt
tabloyu biraz yukarı taşı
User prompt
tabloyu biraz yukarı taşı
User prompt
2x tabloyu biraz yukarı taşı
User prompt
tabloyu biraz yukarı taşı
User prompt
tabloyu biraz yukarı taşı
User prompt
tabloyu biraz yukarı taşı
User prompt
tabloyu tuşların konumuna agöre ortala
User prompt
yazı fontunu biraz küçült
User prompt
tablo nun yazı fontunu 2 katına çıkar
User prompt
yazı fontunu büyüt ve sadece your high score yazısı kalsın
User prompt
liderlik tablosunu sil sadece your high score kalsın
User prompt
Please fix the bug: 'TypeError: Set is not a constructor' in or related to this line: 'storage.leaderboard = Array.from(new Set(storage.leaderboard)).sort(function (a, b) {' Line Number: 243
User prompt
bunun sağlanması için gerekli kodları değiştir
User prompt
Please fix the bug: 'TypeError: Set is not a constructor' in or related to this line: 'storage.leaderboard = Array.from(new Set(storage.leaderboard)).sort(function (a, b) {' Line Number: 275
User prompt
Please fix the bug: 'TypeError: Set is not a constructor' in or related to this line: 'storage.leaderboard = _toConsumableArray(new Set(storage.leaderboard)).sort(function (a, b) {' Line Number: 275
User prompt
Please fix the bug: 'TypeError: Set is not a constructor' in or related to this line: 'storage.leaderboard = Array.from(new Set(storage.leaderboard)).sort(function (a, b) {' Line Number: 243
User prompt
ldierlik tablosunda sadece en yüksek puan yazılacak yani 10 yaparsam sıralama 10,9,8 olmayacak 10,5,4 olacak
User prompt
liderlik tablosundaki puanları sıfırla
User prompt
tuşları çok az yukarı al
User prompt
liderlik tablosunu biraz sağa taşı
User prompt
tuşları biraz sola al
User prompt
liderlik tablosunu biraz sağa taşı
===================================================================
--- original.js
+++ change.js
@@ -142,10 +142,10 @@
LK.gui.top.addChild(scoreTxt);
// Display leaderboard
var playerHighScore = storage.playerHighScore || 0;
var leaderboardTxt = new Text2('Your High Score: ' + playerHighScore, {
- size: 80,
- // Increased font size from 50 to 80
+ size: 160,
+ // Increased font size from 80 to 160
fill: 0xFFFFFF
});
leaderboardTxt.anchor.set(0, 0);
leaderboardTxt.x = buttonUp.x - 200; // Position leaderboard to the left of the buttons